<?php
/**
 * List tables: Custom Fields.
 *
 * @package  Treweler/Admin
 * @version  1.03
 */

if ( ! defined( 'ABSPATH' ) ) {
  exit;
}

if ( class_exists( 'TWER_Admin_List_Table_Custom_Fields', false ) ) {
  return;
}

if ( ! class_exists( 'TWER_Admin_List_Table', false ) ) {
  include_once 'abstract-class-twer-admin-list-table.php';
}

/**
 * TWER_Admin_List_Table_Products Class.
 */
class TWER_Admin_List_Table_Custom_Fields extends TWER_Admin_List_Table {

  /**
   * Post type.
   *
   * @var string
   */
  protected $list_table_type = 'twer-custom-fields';

  /**
   * Constructor.
   */
  public function __construct() {
    parent::__construct();
  }

  /**
   * Define which columns are sortable.
   *
   * @param array $columns Existing columns.
   *
   * @return array
   */
  public function define_sortable_columns( $columns ) {
    $custom = [
      'name'       => 'title',
      'field_key'  => 'field_key',
      'field_type' => 'field_type'
    ];

    return wp_parse_args( $custom, $columns );
  }

  /**
   * Remove actions from CPT ddl
   *
   * @param $actions
   *
   * @return array
   */
  public function define_bulk_actions( $actions ) {
    unset( $actions['edit'] );

    return $actions;
  }

  /**
   * Define which columns to show on this screen.
   *
   * @param array $columns Existing columns.
   *
   * @return array
   */
  public function define_columns( $columns ) {
    if ( empty( $columns ) && ! is_array( $columns ) ) {
      $columns = [];
    }

    unset( $columns['title'], $columns['comments'], $columns['date'], $columns['categories'] );

    $show_columns = [];
    $show_columns['cb'] = '<input type="checkbox" />';
    $show_columns['name'] = esc_html__( 'Name', 'treweler' );
    $show_columns['field_key'] = esc_html__( 'Field Key', 'treweler' );
    $show_columns['field_type'] = esc_html__( 'Field Type', 'treweler' );
    $show_columns['date'] = esc_html__( 'Date', 'treweler' );

    return array_merge( $show_columns, $columns );
  }

  /**
   * Render columm: field_key.
   */
  protected function render_field_key_column() {
    $post_id = isset( $this->object->ID ) ? $this->object->ID : 0;
    $data = twer_get_data( $post_id );
    $field_key = isset( $data->custom_field_key ) ? $data->custom_field_key : '';

    echo esc_html( $field_key );
  }

  /**
   * Render columm: field_type.
   */
  protected function render_field_type_column() {
    $post_id = isset( $this->object->ID ) ? $this->object->ID : 0;
    $data = twer_get_data( $post_id );
    $field_type = isset( $data->custom_field_type ) ? ucfirst( $data->custom_field_type ) : '';
    echo esc_html( $field_type );
  }

  /**
   * Define primary column.
   *
   * @return string
   */
  protected function get_primary_column() {
    return 'name';
  }

  /**
   * Get row actions to show in the list table.
   *
   * @param array $actions Array of actions.
   * @param WP_Post $post Current post object.
   *
   * @return array
   */
  protected function get_row_actions( $actions, $post ) {
    unset( $actions['inline hide-if-no-js'] );
    unset( $actions['edit'] );

    /* translators: %d: post ID. */

    return array_merge( [ 'id' => sprintf( esc_html__( 'ID: %d', 'treweler' ), $post->ID ) ], $actions );
  }

  /**
   * Render column: name.
   */
  protected function render_name_column() {
    global $post;

    $edit_link = get_edit_post_link( $this->object->post_id );
    $title = _draft_or_post_title();

    echo '<strong><a class="row-title" href="' . esc_url( $edit_link ) . '">' . esc_html( $title ) . '</a>';

    _post_states( $post );

    echo '</strong>';

    $parent_id = wp_get_post_parent_id( $this->object->post_id );
    if ( $parent_id > 0 ) {
      echo '&nbsp;&nbsp;&larr; <a href="' . esc_url( get_edit_post_link( $parent_id ) ) . '">' . get_the_title( $parent_id ) . '</a>'; // @codingStandardsIgnoreLine.
    }

    get_inline_data( $post );
  }


  /**
   * Pre-fetch any data for the row each column has access to it. the_marker global is there for bw compat.
   *
   * @param int $post_id Post ID being shown.
   */
  protected function prepare_row_data( $post_id ) {
    global $the_custom_fields;

    if ( empty( $this->object ) || $this->object->post_id !== $post_id ) {
      $the_custom_fields = get_post( $post_id );
      $this->object = $the_custom_fields;
    }
  }

}
